@@ -19,15 +19,19 @@ sub AUTOLOAD {
     $self->_accessor( $key, @_ );
 }
 
+# this class effectively handles any method calls
+sub can { 1 }
+
 sub id {
     my $self = shift;
     $self->_accessor( "id", @_ );
 }
 
-sub store {
-    my $self = shift;
-    $self->_accessor( "store", @_ ) || ref $self;
-}
+## deprecated. Let the base class handle this.
+#    sub store {
+#        my $self = shift;
+#        $self->_accessor( "store", @_ ) || ref $self;
+#    }
 
 sub _accessor {
     my $self = shift;
@@ -44,6 +48,7 @@ sub _accessor {
       : $data;
 }
 
+## password portion of this is no longer necessary, but here for backwards compatibility.
 my %features = (
     password => {
         clear      => ["password"],
@@ -85,7 +90,8 @@ sub supports {
 
 sub for_session {
     my $self = shift;
-    return $self->store && $self->id || $self; # if we have a store and an ID we serialize by ref, otherwise we serialize the whole user
+    
+    return $self; # we serialize the whole user
 }
 
 sub from_session {
